@@ -1,5 +1,5 @@
 from django.contrib import admin
-from django.utils.safestring import mark_safe
+from django.utils.html import format_html
 from edc_adverse_event.modeladmin_mixins import AeInitialModelAdminMixin
 from edc_model_admin import SimpleHistoryAdmin
 from edc_notification.utils import get_email_contacts
@@ -14,7 +14,9 @@ class AeInitialAdmin(AeInitialModelAdminMixin, SimpleHistoryAdmin):
 
     form = AeInitialForm
     email_contact = get_email_contacts("ae_reports")
-    additional_instructions = mark_safe(
+    additional_instructions = format_html(
         "Complete the initial AE report and forward to the TMG. "
-        f'Email to <a href="mailto:{email_contact}">{email_contact}</a>'
+        'Email to <a href="mailto:{}">{}</a>',
+        email_contact,
+        email_contact,
     )
