@@ -1,5 +1,4 @@
 from django import forms
-from edc_action_item.forms import ActionItemFormMixin
 from edc_adverse_event.forms import validate_ae_initial_outcome_date
 from edc_form_validators import FormValidator, FormValidatorMixin
 from edc_registration.modelform_mixins import ModelFormSubjectIdentifierMixin
@@ -12,18 +11,18 @@ class AeReviewFormValidator(FormValidator):
 
 class AeReviewModelFormMixin(
     ModelFormSubjectIdentifierMixin,
-    ActionItemFormMixin,
     FormValidatorMixin,
 ):
     form_validator_cls = AeReviewFormValidator
 
-    subject_identifier = forms.CharField(
-        label="Subject Identifier",
-        required=False,
-        widget=forms.TextInput(attrs={"readonly": "readonly"}),
-    )
-
     def clean(self):
         cleaned_data = super().clean()
         validate_ae_initial_outcome_date(self)
         return cleaned_data
+
+    class Meta:
+        help_text = {"subject_identifier": "(read-only)", "action_identifier": "(read-only)"}
+        widgets = {
+            "subject_identifier": forms.TextInput(attrs={"readonly": "readonly"}),
+            "action_identifier": forms.TextInput(attrs={"readonly": "readonly"}),
+        }
