@@ -5,6 +5,7 @@ from pathlib import Path
 import environ
 from edc_appointment.constants import SCHEDULED_APPT, UNSCHEDULED_APPT
 from edc_constants.constants import COMPLETE
+from edc_protocol_violation.constants import PROTOCOL_INCIDENT
 from edc_utils import get_datetime_from_env
 
 BASE_DIR = str(Path(os.path.dirname(os.path.abspath(__file__))).parent.parent)
@@ -24,8 +25,7 @@ env = environ.Env(
     DJANGO_LIVE_SYSTEM=(bool, False),
     DJANGO_LOGGING_ENABLED=(bool, True),
     DJANGO_SESSION_COOKIE_SECURE=(bool, True),
-    DJANGO_USE_I18N=(bool, True),
-    DJANGO_USE_L10N=(bool, False),
+    DJANGO_USE_I18N=(bool, False),
     DJANGO_USE_TZ=(bool, True),
     DEFENDER_ENABLED=(bool, False),
     EDC_RANDOMIZATION_REGISTER_DEFAULT_RANDOMIZER=(bool, True),
@@ -60,6 +60,7 @@ ETC_DIR = env.str("DJANGO_ETC_FOLDER")
 
 TEST_DIR = os.path.join(BASE_DIR, APP_NAME, "tests")
 
+# INTERNAL_IPS = ["127.0.0.1"]
 ALLOWED_HOSTS = ["*"]  # env.list('DJANGO_ALLOWED_HOSTS')
 
 ENFORCE_RELATED_ACTION_ITEM_EXISTS = False
@@ -80,13 +81,12 @@ INSTALLED_APPS = [
     "django.contrib.messages",
     "django.contrib.staticfiles",
     "django.contrib.sites",
+    # "debug_toolbar",
     "defender",
     "multisite",
     "django_crypto_fields.apps.AppConfig",
     "django_revision.apps.AppConfig",
     "django_extensions",
-    "django_celery_results",
-    "django_celery_beat",
     "logentry_admin",
     "simple_history",
     "storages",
@@ -103,6 +103,7 @@ INSTALLED_APPS = [
     "edc_device.apps.AppConfig",
     "edc_dashboard.apps.AppConfig",
     "edc_data_manager.apps.AppConfig",
+    "edc_egfr.apps.AppConfig",
     "edc_export.apps.AppConfig",
     "edc_facility.apps.AppConfig",
     "edc_fieldsets.apps.AppConfig",
@@ -164,6 +165,7 @@ if not DEFENDER_ENABLED:
     INSTALLED_APPS.pop(INSTALLED_APPS.index("defender"))
 
 MIDDLEWARE = [
+    # "debug_toolbar.middleware.DebugToolbarMiddleware",
     "django.middleware.security.SecurityMiddleware",
     "django.contrib.sessions.middleware.SessionMiddleware",
     "django.middleware.common.CommonMiddleware",
@@ -186,6 +188,7 @@ MIDDLEWARE.extend(
         "edc_lab_dashboard.middleware.DashboardMiddleware",
         "edc_adverse_event.middleware.DashboardMiddleware",
         # 'simple_history.middleware.HistoryRequestMiddleware'
+        # "django_cprofile_middleware.middleware.ProfilerMiddleware",
     ]
 )
 
@@ -254,13 +257,6 @@ WSGI_APPLICATION = f"{APP_NAME}.wsgi.application"
 
 AUTHENTICATION_BACKENDS = ["edc_auth.backends.ModelBackendWithSite"]
 
-AUTH_PASSWORD_VALIDATORS = [
-    {"NAME": "django.contrib.auth.password_validation.UserAttributeSimilarityValidator"},
-    {"NAME": "django.contrib.auth.password_validation.MinimumLengthValidator"},
-    {"NAME": "django.contrib.auth.password_validation.CommonPasswordValidator"},
-    {"NAME": "django.contrib.auth.password_validation.NumericPasswordValidator"},
-]
-
 PASSWORD_HASHERS = [
     "django.contrib.auth.hashers.Argon2PasswordHasher",
     "django.contrib.auth.hashers.PBKDF2PasswordHasher",
@@ -280,19 +276,12 @@ AUTH_PASSWORD_VALIDATORS = [
 # Internationalization
 # https://docs.djangoproject.com/en/1.11/topics/i18n/
 
-LANGUAGE_CODE = env.str("DJANGO_LANGUAGE_CODE")
-
+USE_I18N = False  # disable trans
+USE_L10N = False  # set to False so DATE formats below are used
+USE_TZ = True
+LANGUAGE_CODE = env.str("DJANGO_LANGUAGE_CODE")  # ignored if USE_L10N = False
 LANGUAGES = [x.split(":") for x in env.list("DJANGO_LANGUAGES")] or (("en", "English"),)
-
 TIME_ZONE = env.str("DJANGO_TIME_ZONE")
-
-USE_I18N = env("DJANGO_USE_I18N")
-
-# set to False so DATE formats below are used
-USE_L10N = env("DJANGO_USE_L10N")
-
-USE_TZ = env("DJANGO_USE_TZ")
-
 DATE_INPUT_FORMATS = ["%Y-%m-%d", "%d/%m/%Y"]
 DATETIME_INPUT_FORMATS = [
     "%Y-%m-%d %H:%M:%S",  # '2006-10-25 14:30:59'
@@ -365,15 +354,22 @@ LAB_DASHBOARD_URL_NAMES = env.dict("DJANGO_LAB_DASHBOARD_URL_NAMES")
 
 # edc-diagnosis
 EDC_DX_LABELS = dict(hiv="HIV", dm="Diabetes", htn="Hypertension", chol="High Cholesterol")
-# edc-label
-EDC_LABEL_BROWSER_PRINT_PAGE_AUTO_BACK = env("EDC_LABEL_BROWSER_PRINT_PAGE_AUTO_BACK")
+
+# edc-egfr
+EDC_EGFR_DROP_NOTIFICATION_MODEL = "meta_subject.egfrdropnotification"
 
 # edc_facility
 HOLIDAY_FILE = env.str("DJANGO_HOLIDAY_FILE")
 
+# edc-label
+EDC_LABEL_BROWSER_PRINT_PAGE_AUTO_BACK = env("EDC_LABEL_BROWSER_PRINT_PAGE_AUTO_BACK")
+
 # edc-mnsi
 EDC_MNSI_MODEL = "meta_subject.mnsi"
 
+# edc-protocol-incident
+EDC_PROTOCOL_VIOLATION_TYPE = PROTOCOL_INCIDENT
+
 # edc-qol
 EDC_QOL_EQ5D3L_MODEL = "meta_subject.eq5d3l"
 
@@ -433,8 +429,8 @@ AUTO_CREATE_KEYS = env("DJANGO_AUTO_CREATE_KEYS")
 EXPORT_FOLDER = env.str("DJANGO_EXPORT_FOLDER") or os.path.expanduser("~/")
 
 # django_simple_history
-SIMPLE_HISTORY_PERMISSIONS_ENABLED = env.str("SIMPLE_HISTORY_PERMISSIONS_ENABLED")
-SIMPLE_HISTORY_REVERT_DISABLED = env.str("SIMPLE_HISTORY_REVERT_DISABLED")
+SIMPLE_HISTORY_REVERT_DISABLED = False
+SIMPLE_HISTORY_ENFORCE_HISTORY_MODEL_PERMISSIONS = True
 
 FQDN = env.str("DJANGO_FQDN")  # ???
 INDEX_PAGE = env.str("DJANGO_INDEX_PAGE")
