@@ -20,9 +20,7 @@ class TestLabs(TestCase):
         self.assertEqual("meta_subject.subjectrequisition", obj.requisition_model)
 
     def test_panel_model(self):
-        for panel in site_labs.get(
-            lab_profile_name="subject_lab_profile"
-        ).panels.values():
+        for panel in site_labs.get(lab_profile_name="subject_lab_profile").panels.values():
             self.assertEqual(panel.requisition_model, "meta_subject.subjectrequisition")
 
     def test_panels_exist(self):
