@@ -1,8 +1,8 @@
-from copy import copy
+from typing import Tuple
 
 from django.contrib import admin
-from edc_action_item import action_fields, action_fieldset_tuple
-from edc_data_manager.data_manager_modeladmin_mixin import DataManagerModelAdminMixin
+from edc_action_item import ActionItemModelAdminMixin, action_fieldset_tuple
+from edc_data_manager.modeladmin_mixins import DataManagerModelAdminMixin
 from edc_model_admin import SimpleHistoryAdmin, audit_fieldset_tuple
 from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin
 
@@ -15,7 +15,10 @@ from ..models import PregnancyNotification
 
 @admin.register(PregnancyNotification, site=meta_prn_admin)
 class PregnancyNotificationAdmin(
-    DataManagerModelAdminMixin, ModelAdminSubjectDashboardMixin, SimpleHistoryAdmin
+    DataManagerModelAdminMixin,
+    ActionItemModelAdminMixin,
+    ModelAdminSubjectDashboardMixin,
+    SimpleHistoryAdmin,
 ):
 
     form = PregnancyNotificationForm
@@ -43,25 +46,22 @@ class PregnancyNotificationAdmin(
         audit_fieldset_tuple,
     )
 
-    list_display = (
-        "subject_identifier",
-        "dashboard",
-        "edd",
-        "may_contact",
-    )
-
-    list_filter = ("edd", "may_contact")
-
     radio_fields = {
         "bhcg_confirmed": admin.VERTICAL,
         "may_contact": admin.VERTICAL,
     }
 
-    search_fields = ("subject_identifier", "action_identifier", "tracking_identifier")
+    def get_list_display(self, request) -> Tuple[str, ...]:
+        list_display = super().get_list_display(request)
+        custom_fields = (
+            "subject_identifier",
+            "dashboard",
+            "edd",
+            "may_contact",
+        )
+        return custom_fields + tuple(f for f in list_display if f not in custom_fields)
 
-    def get_readonly_fields(self, request, obj=None):
-        fields = super().get_readonly_fields(request, obj)
-        action_flds = copy(list(action_fields))
-        action_flds.remove("action_identifier")
-        fields = list(action_flds) + list(fields)
-        return fields
+    def get_list_filter(self, request) -> Tuple[str, ...]:
+        list_filter = super().get_list_display(request)
+        custom_fields = ("edd", "may_contact")
+        return custom_fields + tuple(f for f in list_filter if f not in custom_fields)
