@@ -1,3 +1,5 @@
+from typing import Tuple
+
 from django.contrib import admin
 from django_audit_fields.admin import audit_fieldset_tuple
 
@@ -33,7 +35,7 @@ class ScreeningPartOneAdmin(SubjectScreeningAdmin):
 
     fieldsets = get_fieldsets()
 
-    readonly_fields = (
+    readonly_fields: Tuple[str, ...] = (
         *part_two_fields,
         *part_three_fields,
         *calculated_fields,
