@@ -1,4 +1,8 @@
-from .eligibility import MetaEligibility, SubjectScreeningEligibilityError
+from .eligibility import (
+    MetaEligibility,
+    SubjectScreeningEligibilityError,
+    get_display_label,
+)
 from .eligibility_part_one import EligibilityPartOne
 from .eligibility_part_three import EligibilityPartThreePhaseThree
 from .eligibility_part_two import EligibilityPartTwo
