@@ -1,5 +1,6 @@
 from django import forms
-from edc_constants.constants import NEG, NO, POS, YES
+from edc_constants.constants import NO, YES
+from edc_egfr.form_validator_mixins import EgfrCkdEpiFormValidatorMixin
 from edc_form_validators import FormValidator
 from edc_glucose.form_validators import (
     FastingFormValidatorMixin,
@@ -7,7 +8,7 @@ from edc_glucose.form_validators import (
     GlucoseFormValidatorMixin,
 )
 from edc_glucose.utils import validate_glucose_as_millimoles_per_liter
-from edc_reportable import BmiFormValidatorMixin, EgfrCkdEpiFormValidatorMixin
+from edc_reportable import BmiFormValidatorMixin
 from edc_vitals.form_validators import (
     BloodPressureFormValidatorMixin,
     WeightHeightBmiFormValidatorMixin,
@@ -162,15 +163,6 @@ class ScreeningPartThreeFormValidator(
         )
         self.required_if(YES, field="urine_bhcg_performed", field_required="urine_bhcg_date")
 
-        if self.instance.pregnant == YES and self.cleaned_data.get("urine_bhcg_value") == NEG:
-            raise forms.ValidationError(
-                {"urine_bhcg_value": "Invalid, part one says subject is pregnant"}
-            )
-        elif self.instance.pregnant == NO and self.cleaned_data.get("urine_bhcg_value") == POS:
-            raise forms.ValidationError(
-                {"urine_bhcg_value": "Invalid, part one says subject is not pregnant"}
-            )
-
     def require_all_vitals_fields(self):
         require_all = False
         fields = part_three_vitals_fields
