@@ -9,7 +9,6 @@ from edc_screening.screening_identifier import (
 
 from .calculated_model_mixin import CalculatedModelMixin
 from .eligibility_model_mixin import EligibilityModelMixin
-from .part_four_field_model_mixin import PartFourFieldsModelMixin
 from .part_one_fields_model_mixin import PartOneFieldsModelMixin
 from .part_three_fields_model_mixin import PartThreeFieldsModelMixin
 from .part_two_fields_model_mixin import PartTwoFieldsModelMixin
@@ -28,7 +27,6 @@ class SubjectScreening(
     PartOneFieldsModelMixin,
     PartTwoFieldsModelMixin,
     PartThreeFieldsModelMixin,
-    PartFourFieldsModelMixin,
     EligibilityModelMixin,
     CalculatedModelMixin,
     ScreeningModelMixin,
@@ -40,7 +38,7 @@ class SubjectScreening(
     contact_number = EncryptedCharField(
         validators=[RegexValidator(r"^[0-9\-\(\)\ ]+$", message="Enter a valid number")],
         null=True,
-        help_text="Provide a contact number if repeating glucose measures",
+        help_text="Provide a contact number if repeating glucose measures (Encryption: RSA)",
     )
 
     def save(self, *args, **kwargs):
