@@ -10,7 +10,7 @@ from .complications_admin import ComplicationsAdmin
 from .complications_glycemia_admin import ComplicationsGlycemiaAdmin
 from .concomitant_medication_admin import ConcomitantMedicationAdmin
 from .delivery_admin import DeliveryAdmin
-from .egfr_notification_admin import EgfrNotificationAdmin
+from .egfr_drop_notification_admin import EgfrDropNotificationAdmin
 from .eq5d3l_admin import Eq5d3lAdmin
 from .followup_examination_admin import FollowupExaminationAdmin
 from .followup_vitals_admin import FollowupVitalsAdmin
