@@ -1,4 +1,5 @@
 from django.contrib import admin
+from edc_action_item import action_fieldset_tuple
 from edc_lab_panel.panels import blood_glucose_panel
 from edc_lab_results.admin import BloodResultsModelAdminMixin
 from edc_lab_results.fieldsets import BloodResultFieldset
@@ -16,7 +17,10 @@ class BloodResultsGluAdmin(BloodResultsModelAdminMixin, CrfModelAdmin):
     form = BloodResultsGluForm
     fieldsets = BloodResultFieldset(
         blood_glucose_panel,
-        extra_fieldsets=((2, ("Fasting", {"fields": ["fasting"]})),),
+        extra_fieldsets=[
+            (2, ("Fasting", {"fields": ["fasting"]})),
+            (-1, action_fieldset_tuple),
+        ],
     ).fieldsets
 
     radio_fields = {
