@@ -1,4 +1,5 @@
 from django.contrib import admin
+from edc_action_item import action_fieldset_tuple
 from edc_lab_results.admin import BloodResultsModelAdminMixin
 from edc_lab_results.fieldsets import BloodResultFieldset
 
@@ -12,5 +13,9 @@ from ..modeladmin import CrfModelAdmin
 class BloodResultsLftAdmin(BloodResultsModelAdminMixin, CrfModelAdmin):
     form = BloodResultsLftForm
     fieldsets = BloodResultFieldset(
-        BloodResultsLft.lab_panel, model_cls=BloodResultsLft
+        BloodResultsLft.lab_panel,
+        model_cls=BloodResultsLft,
+        extra_fieldsets=[
+            (-1, action_fieldset_tuple),
+        ],
     ).fieldsets
