@@ -11,7 +11,7 @@ from .blood_results import (
 from .complications_glycemia_form import ComplicationsGlycemiaForm
 from .concomitant_medication_form import ConcomitantMedicationForm
 from .delivery_form import DeliveryForm
-from .egfr_notification_form import EgfrNotificationForm
+from .egfr_drop_notification_form import EgfrDropNotificationForm
 from .eq53d3l_form import Eq5d3lForm
 from .followup_examination_form import FollowupExaminationForm
 from .followup_vitals_form import FollowupVitalsForm
