@@ -1,5 +1,5 @@
 from django import forms
-from edc_crf.modelform_mixins import CrfModelFormMixin
+from edc_crf.modelform_mixins import InlineCrfModelFormMixin
 from edc_form_validators.form_validator import FormValidator
 
 from ..constants import LIVE_AT_TERM, LIVE_PRETERM
@@ -16,7 +16,7 @@ class BirthOutcomesFormValidator(FormValidator):
         )
 
 
-class BirthOutcomesForm(CrfModelFormMixin, forms.ModelForm):
+class BirthOutcomesForm(InlineCrfModelFormMixin, forms.ModelForm):
 
     form_validator_cls = BirthOutcomesFormValidator
 
