@@ -1,5 +1,8 @@
-from edc_blood_results import BLOOD_RESULTS_FBC_ACTION
-from edc_blood_results.model_mixins import (
+from edc_crf.crf_with_action_model_mixin import CrfWithActionModelMixin
+from edc_lab.model_mixins import CrfWithRequisitionModelMixin
+from edc_lab_panel.panels import fbc_panel
+from edc_lab_results import BLOOD_RESULTS_FBC_ACTION
+from edc_lab_results.model_mixins import (
     BloodResultsModelMixin,
     HaemoglobinModelMixin,
     HctModelMixin,
@@ -10,9 +13,6 @@ from edc_blood_results.model_mixins import (
     RbcModelMixin,
     WbcModelMixin,
 )
-from edc_crf.crf_with_action_model_mixin import CrfWithActionModelMixin
-from edc_lab.model_mixins import CrfWithRequisitionModelMixin
-from edc_lab_panel.panels import fbc_panel
 from edc_model import models as edc_models
 
 
