@@ -1,14 +1,14 @@
-from edc_blood_results import BLOOD_RESULTS_LIPID_ACTION
-from edc_blood_results.model_mixins import (
+from edc_crf.crf_with_action_model_mixin import CrfWithActionModelMixin
+from edc_lab.model_mixins import CrfWithRequisitionModelMixin
+from edc_lab_panel.panels import lipids_panel
+from edc_lab_results import BLOOD_RESULTS_LIPID_ACTION
+from edc_lab_results.model_mixins import (
     BloodResultsModelMixin,
     CholModelMixin,
     HdlModelMixin,
     LdlModelMixin,
     TrigModelMixin,
 )
-from edc_crf.crf_with_action_model_mixin import CrfWithActionModelMixin
-from edc_lab.model_mixins import CrfWithRequisitionModelMixin
-from edc_lab_panel.panels import lipids_panel
 from edc_model import models as edc_models
 
 
