@@ -5,8 +5,6 @@ from edc_model import models as edc_models
 from edc_reference.model_mixins import ReferenceModelMixin
 
 
-class SubjectRequisition(
-    RequisitionModelMixin, ReferenceModelMixin, edc_models.BaseUuidModel
-):
+class SubjectRequisition(RequisitionModelMixin, ReferenceModelMixin, edc_models.BaseUuidModel):
     class Meta(RequisitionModelMixin.Meta, edc_models.BaseUuidModel.Meta):
         pass
