@@ -1,4 +1,4 @@
-from django.test import TestCase, tag
+from django.test import TestCase
 
 from meta_screening.tests.meta_test_case_mixin import MetaTestCaseMixin
 from meta_subject.models import StudyMedication
@@ -9,6 +9,5 @@ class TestPhysicalExam(MetaTestCaseMixin, TestCase):
         super().setUp()
         self.subject_visit = self.get_subject_visit()
 
-    @tag("1")
     def test_ok(self):
         StudyMedication(subject_visit=self.subject_visit)
